@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# Author: Barney Walker <barney@labstep.com>
+# Author: Labstep <dev@labstep.com>
 
 import json
 from pathlib import Path
@@ -144,7 +144,7 @@ def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
         if entityNameInFolderName and hasattr(
                 entity, 'name') and entity.name is not None:
             santitisedName = sanitize_filepath(
-                entity.name.replace('/', ' ').replace('\\', ' '))
+                entity.name.replace('/', ' ').replace('\\', ' '))[:50].strip()
             folderName = f"{entity.id} - {santitisedName}"
             if len(folderName) > 255:
                 folderName = str(entity.id)
